##  Data Privacy
You can adjust the data privacy level for subscriptions by choosing between 'Normal' and 'Relaxed.' In 'Relaxed' mode, users can view other subscribers in the subscription filter of the Inventory and use it to filter the Fact Sheets. However, in 'Normal' mode, users will not see other subscribers in the filter. For more, see [Managing Data Privacy](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to create, edit, and delete subscription roles and manage settings like enabling the 'Accountable' type, limiting multiple subscriptions, and enforcing mandatory role selection.").
